#
# spec file for package sdcc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sdcc
Version:        3.6.0
Release:        lp150.8.1
Summary:        Small Device C Compiler
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Development/Languages/C and C++
Url:            http://sdcc.sourceforge.net/
Source:         http://downloads.sourceforge.net/%{name}/%{name}-src-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
Patch0:         0001-Doc-Disable-fallback-to-dvipdfm-remove-non-pdftex-ta.patch
Patch2:         sdcc_enable_additional_target_libs.patch
BuildRequires:  bison
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gputils
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  python-devel
# documentation
BuildRequires:  inkscape
BuildRequires:  lyx
BuildRequires:  makeinfo
BuildRequires:  texlive-babel-english
%if 0%{?suse_version} > 1320
BuildRequires:  texlive-makeindex-bin
%endif
BuildRequires:  texlive-fancyhdr
%if 0%{?suse_version} > 1500
BuildRequires:  texlive-footnotehyper
%endif
BuildRequires:  texlive-latex
BuildRequires:  texlive-makeindex
BuildRequires:  texlive-ulem
BuildRequires:  tex(footnote.sty)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SDCC is a C compiler for 8051 class and similar microcontrollers.
The package includes the compiler, assemblers and linkers, a device
simulator and a core library. The processors supported (to a varying
degree) include the 8051, ds390, z80, hc08, and PIC.

%package        doc
Summary:        Documentation for the SDCC C compiler
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
SDCC is a C compiler for 8051 class and similar microcontrollers.
The package includes the compiler, assemblers and linkers, a device
simulator and a core library. The processors supported (to a varying
degree) include the 8051, ds390, z80, hc08, and PIC.

This package contains documentation for SDCC C compiler.

%package        libc-sources
Summary:        Small Device C Compiler
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description    libc-sources
SDCC is a C compiler for 8051 class and similar microcontrollers.
The package includes the compiler, assemblers and linkers, a device
simulator and a core library. The processors supported (to a varying
degree) include the 8051, ds390, z80, hc08, and PIC.

This package contains sources for the C library and other files for
development.

%prep
%setup -q
rm support/regression/tests/bug3304184.c
# remove non-free libraries, see doc/README.txt: Licenses
find device/non-free/ \( -iname \*.h -o -iname \*.c -o -iname \*.S \) -delete
%patch0 -p1
%patch2 -p1
sed -i '1 s@.*@#!/usr/bin/python2@' support/scripts/as2gbmap.py

%build
# Force configure to ignore missing, but unused TeX binaries
export LATEX2HTML=/usr/bin/true
export DVIPDFM=/usr/bin/true
CFLAGS="%{optflags} -fno-strict-aliasing" \
%configure \
    --docdir=%{_docdir}/sdcc \
    --disable-non-free \
    %if 0%{?suse_version} >= 1320
    --enable-doc
    %endif

inkscape --export-area-drawing --export-pdf=doc/MCS51_named.pdf doc/MCS51_named.svg

make %{?_smp_mflags}

%install
%make_install

# install documentation
mkdir -p %{buildroot}%{_docdir}/%{name}/sdas
cp sdas/doc/* %{buildroot}%{_docdir}/%{name}/sdas

mkdir -p %{buildroot}%{_datadir}/emacs/site-lisp
mv %{buildroot}%{_bindir}/*.el %{buildroot}%{_datadir}/emacs/site-lisp

# remove useless file
rm %{buildroot}%{_docdir}/%{name}/INSTALL.txt

# remove strange stuff (installed by mistake?)
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic1{4,6}/.checkdevices
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic1{4,6}/aclocal.m4
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic1{4,6}/stamp-h1
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic1{4,6}/libsdcc/.dirstamp

# remove built libraries from source folder
find %{buildroot}%{_datadir}/%{name}/lib/src/pic16/ -iname \*lib*.a -delete
find %{buildroot}%{_datadir}/%{name}/lib/src/pic14/ -iname \*lib*.a -delete

# remove documentation of bundled libbfd, conflicts with binutils
rm %{buildroot}%{_infodir}/bfd.info*

# remove PPC embedspu (unneeded unless you have an AVR etc with a cell engine), conflicts with binutils
rm -f %{buildroot}%{_bindir}/embedspu

# duplicates
%fdupes -s %{buildroot}%{_datadir}/%{name}/lib/src
%fdupes -s %{buildroot}%{_bindir}

# move src away temporarily, as we do not want symlinks across packages
mv %{buildroot}%{_datadir}/%{name}/lib/src %{buildroot}%{_datadir}/%{name}/src
%fdupes -s %{buildroot}%{_datadir}/%{name}/lib
mv %{buildroot}%{_datadir}/%{name}/src %{buildroot}%{_datadir}/%{name}/lib/src

%files
%doc ChangeLog doc/README.txt
%license COPYING
%exclude %{_docdir}/%{name}/ucsim/
%exclude %{_docdir}/%{name}/sdas/
%exclude %{_docdir}/%{name}/*.pdf
%{_bindir}/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/include
%{_datadir}/%{name}/lib
%exclude %{_datadir}/%{name}/lib/src
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/site-lisp/*.el

%files libc-sources
%{_datadir}/%{name}/lib/src

%files doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ucsim
%{_docdir}/%{name}/sdas
%if 0%{?suse_version} >= 1320
%{_docdir}/%{name}/sdccman.pdf
%endif

%changelog
* Thu Dec 13 2018 Michal Suchanek <msuchanek@suse.de>
- Fix Tumbleweed build.
- Instead of including prebuilt MCS51_named.pdf build it during package build.
  Besides avoiding the ImageMagick problem with interpreting PS this also
  avoids rasterising the image.
* Thu Oct 18 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Delete PowerPC embedspu script from sdbinutils which conflicts with binutils,
  fixes boo#1112433
* Tue Oct  2 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add pre-converted MCS51_named.pdf to sources, to avoid the lossy
  SVG -> EPS (rasterized) -> PDF conversion of the distributed SVG.
  [bsc#1109976]
* Sat Feb  3 2018 stefan.bruens@rwth-aachen.de
- Add explicit BuildRequires: for footnote.sty
- Remove handling of obsolete distribution versions
- Cleanup spec, remove code necessary for older sdcc versions
- Drop dvipdfm and latex2html BuildRequires:, these are not really
  used
- Add 0001-Doc-Disable-fallback-to-dvipdfm-remove-non-pdftex-ta.patch
  * do not build dvi file, but use pdflatex to build references (.aux)
  * use PDF version 1.5 instead of 1.3, reduces sdccman.pdf size by 40%%
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Sep 20 2016 stefan.bruens@rwth-aachen.de
- Spec file cleanup:
  * disable non-free build, instead of deleting build files
  * do not install bfd info, which conflicts with binutils package,
    and is useless, as sdcc links libbfd statically
  * cleanup %%doc
* Tue Sep  6 2016 wk@ire.pw.edu.pl
- Fixed info file uninstall
* Mon Sep  5 2016 wk@ire.pw.edu.pl
- Update to version 3.5.0
  * Merged upstream binutils 2.25
  * New memory management with lower overhead
  * Changed default language dialect to --std-sdcc11
  * Diagnostic for missing type specifier: No implicit int outside of C90 mode anymore
  * C11 generic selections
  * char type is now unsigned by default (old behaviour can be restored using --fsigned-char)
  * Character constants are now of type int instead of char.
  * ISO C95 and ISO C11 wide character constants
  * ISO C95 and ISO C11 wide string literals
  * Basic standard library support for wide characters: c16rtomb(), mbrtoc16(), mbsinit(), mbtowc(), mbrlen(), mbrtoc32, c32rtomb(), mbrtowc(), wcrtomb(), mblen(), wctomb()
  * Treat all ports the same in the manual (i.e. mcs51-specific stuff is now clearly described as such)
  * Reorganized interrupt handling for z80, z180, r2k, r3ka, tlcs90, gbz80 backends
  * Workaround for stm8 division hardware bug
  * ELF/DWARF support for stm8
  * Output symbol table for ELF
  * pic16 port now uses standard-compliant crt0iz that initializes static and globals to 0 by default
- Numerous feature requests and bug fixes are included as well.
- Removed patch sdcc_add_ppc64le_suse_support.patch (applied upstream)
- Modified patch sdcc_enable_additional_target_libs.patch
* Tue Aug 16 2016 dimstar@opensuse.org
- BuildRequire texlive-xetex-bin in plus in openSUSE Tumbleweed in
  order to workaround boo#992360.
* Fri Oct 30 2015 tobias.johannes.klausmann@mni.thm.de
- Build additional libraries sdcc can link against
- Add patch sdcc_enable_additional_target_libs.patch
* Tue Aug 25 2015 dmitry_r@opensuse.org
- Add _constraints file, 3 Gb of memory are required
* Tue Aug 18 2015 normand@linux.vnet.ibm.com
- new patch to build on ppc64le
  sdcc_add_ppc64le_suse_support.patch
* Fri Jun 26 2015 dmitry_r@opensuse.org
- Update to version 3.5.0
  * Changed default language dialect from --std-sdcc89 to --std-sdcc99
  * Reorganized and updated manual
  * Reduced memory consumption (most noticeable for high --max-allocs-per-node)
  * Faster compilation for stm8 (most noticeable for high --max-allocs-per-node)
  * atoll() function for conversion of strings to long long
  * __z88dk_fastcall and __z88dk_callee calling conventions for more
    efficient function calls and better compability with z88dk
  * --lospre-unsafe-read renamed to --allow-unsafe-read
- Drop obsolete
  * sdcc-remove-strndup.patch
  * sdcc-libiberty.patch
* Sun Nov 30 2014 wk@ire.pw.edu.pl
- Fixed build for Tumbleweed and Factory by adding patch
    sdcc-remove-strndup.patch
- added patch sdcc-libiberty.patch
* Thu Jul 31 2014 dmitry_r@opensuse.org
- Change package license to GPL-2.0+ and GPL-3.0+ [bnc#889723]
* Mon Jul 28 2014 dmitry_r@opensuse.org
- spec file cleanup
- Remove non-free libraries
- Move libc sources to separate package
* Thu Oct  4 2012 Wojciech Kazubski <wk@ire.pw.edu.pl> -3.2.0-13
- update to 3.2.0
* Mon Sep  3 2012 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to 3.1.0
* Fri Nov 30 2007 Tuukka Pasanen <rpms@ilmi.fi>
- New version
* Tue Feb 20 2007 Tuukka Pasanen <rpms@ilmi.fi>
- Initial build
